pub trait AeadEncryption<Aad> {
// Required methods
fn encrypt_value<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
aad: &'life1 Aad,
plain_text: &'life2 SecretValue,
encryption_key: &'life3 DataEncryptionKey,
) -> Pin<Box<dyn Future<Output = KmsAeadResult<CipherText>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn decrypt_value<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
aad: &'life1 Aad,
cipher_text: &'life2 CipherText,
encryption_key: &'life3 DataEncryptionKey,
) -> Pin<Box<dyn Future<Output = KmsAeadResult<SecretValue>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
}Expand description
A trait that defines the encryption and decryption of a value using a data encryption key and additional authenticated data (AEAD).
Required Methods
fn encrypt_value<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
aad: &'life1 Aad,
plain_text: &'life2 SecretValue,
encryption_key: &'life3 DataEncryptionKey,
) -> Pin<Box<dyn Future<Output = KmsAeadResult<CipherText>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn decrypt_value<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
aad: &'life1 Aad,
cipher_text: &'life2 CipherText,
encryption_key: &'life3 DataEncryptionKey,
) -> Pin<Box<dyn Future<Output = KmsAeadResult<SecretValue>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".